@@ -8,9 +8,9 @@ import sys
 import time
 import traceback
 
-from .scheduler import ThreadedScheduler, method
-from .utils import load_class_from_name
-from . import basemodule
+from scheduler import ThreadedScheduler, method
+from utils import load_class_from_name
+import basemodule
 
 
 class TaskManager(object):
